@@ -99,6 +99,8 @@ def set_value(dictionary, keys, value):
 class BaseField(object):
     _auto_creation_counter = 0
 
+    ALLOWED_TYPES = None
+
     def __init__(self, initial=Empty, proto_field=None, default=None, custom=False, context=None, **kwargs):
         # Increase the auto creation counter
         self._auto_creation_counter = BaseField._auto_creation_counter
@@ -293,6 +295,24 @@ class IntField(BaseField):
         return _repr
 
 
+class FloatField(BaseField):
+
+    def to_internal_value(self, data):
+        try:
+            return float(data)
+        except (TypeError, ValueError):
+            raise ValueError('Expected a number.')
+
+    def to_representation(self, value):
+        return float(value) if value is not None else None
+
+    def to_protobuf(self, value):
+        _repr = self.to_representation(value)
+        if _repr is None:
+            return None
+        return _repr
+
+
 class ObjectIdField(BaseField):
 
     def to_internal_value(self, data):
@@ -340,7 +360,19 @@ class CustomField(BaseField):
 
 class ListField(BaseField):
 
+    ALLOWED_TYPES = ['CharField', 'DateTimeField', 'IntField', 'ObjectIdField', 'CustomField', 'BooleanField', 'FloatField']
+
     def __init__(self, type=None, **kwargs):
+        if type.__class__.__name__ not in self.ALLOWED_TYPES:
+            raise ValueError(
+                'type {!r} is not allowed for {!r}. '
+                'Allowed types are: {}'.format(
+                    type.__class__.__name__,
+                    self.__class__.__name__,
+                    ', '.join(self.ALLOWED_TYPES)
+                )
+            )
+
         self.child = type
         super().__init__(**kwargs)
 
@@ -365,7 +397,19 @@ class ListField(BaseField):
 
 class DictField(BaseField):
 
+    ALLOWED_TYPES = ['ListField']
+
     def __init__(self, type=None, **kwargs):
+        if type.__class__.__name__ not in self.ALLOWED_TYPES:
+            raise ValueError(
+                'type {!r} is not allowed for {!r}. '
+                'Allowed types are: {}'.format(
+                    type.__class__.__name__,
+                    self.__class__.__name__,
+                    ', '.join(self.ALLOWED_TYPES)
+                )
+            )
+
         self.child = type
         super().__init__(**kwargs)
 
@@ -397,11 +441,13 @@ class DictField(BaseField):
 class DateTimeField(BaseField):
 
     def __init__(self, format=None, **kwargs):
-        self.format = format
+        self.format = format or '%Y-%m-%d %H:%M:%S'
         super().__init__(**kwargs)
 
     def to_internal_value(self, data):
         if data is not Empty:
+            if isinstance(data, datetime):
+                return data.strftime(self.format) if self.format else data
             if self.format:
                 data = datetime.strptime(data, self.format)
             else:
@@ -411,7 +457,7 @@ class DateTimeField(BaseField):
 
     def to_representation(self, value):
         if value is not None:
-            if self.format:
+            if self.format and isinstance(value, datetime):
                 return value.strftime(self.format)
             return value
         return value
@@ -421,3 +467,42 @@ class DateTimeField(BaseField):
         if _repr is None:
             return None
         return _repr
+
+
+class TimestampField(BaseField):
+
+    ALLOWED_TYPES = ['IntField', 'CharField', 'FloatField']
+
+    def __init__(self, type=None, **kwargs):
+        if type.__class__.__name__ not in self.ALLOWED_TYPES:
+            raise ValueError(
+                'type {!r} is not allowed for {!r}. '
+                'Allowed types are: {}'.format(
+                    type.__class__.__name__,
+                    self.__class__.__name__,
+                    ', '.join(self.ALLOWED_TYPES)
+                )
+            )
+
+        self.type = type or IntField()
+        super().__init__(**kwargs)
+
+    def to_internal_value(self, data):
+        if data is not Empty:
+            if isinstance(data, datetime):
+                return data.timestamp()
+            return self.type.to_internal_value(data)
+        return data
+
+    def to_representation(self, value):
+        if value is not None:
+            if isinstance(value, datetime):
+                return value.timestamp()
+            return self.type.to_representation(value)
+        return value
+
+    def to_protobuf(self, value):
+        _repr = self.to_representation(value)
+        if _repr is None:
+            return None
+        return _repr
