@@ -116,7 +116,7 @@ class BaseSerializer(BaseField):
         :rtype: list
         """
 
-        if not self.pb:
+        if not self.child.pb:
             raise AttributeError(
                 'Protobuf is not defined in {!r} serializer. '
                 'You can define it in meta variable with `schema` key.'
